const selenoidVideoApi = require('../index.js');

const rec = selenoidVideoApi.getWdioHooks({
  usingAllure: true,
  saveAllVideos: false,
  videoMinTime: 100,
});


const config = {
  // =================================
  // Hooks bound to selenoid-video-api
  // =================================
  before: function (capabilities, specs) {
    // Setup the browser window
    browser.windowHandlePosition({x: 0, y: 0});
    browser.windowHandleSize({width: 1320, height: 768});

    rec.before(browser, config.baseUrl);
  },
  beforeTest: function (test) {
    rec.beforeTest(browser, test, {
      size: '1320x768',
      framerate: 15,
    });
  },
  afterTest: function (test) {
    rec.afterTest(browser, test, config.outputDir);
  },
  after: function (result, capabilities, specs) {
    rec.after(browser);
  },
  onComplete: function(exitCode, config, capabilities) {
    rec.onComplete();
  },


  // ============
  // Capabilities
  // ============
  capabilities: [{
      maxInstances: 1,
      browserName: 'chrome',
      enableVideo: true,
      enableVNC: true,
  }],


  // ===============
  // Custom settings
  // ===============
  specs: [
    './src/**/*.e2e.js',                        // Which files to run
  ],
  outputDir: './e2e/results/',                  // Output dir for the report
  baseUrl: 'localhost:8080',                    // Baseurl
  host: 'localhost',                            // Selenium host url
  reporters: ['dot', 'allure'],                 // Reporters: Dot for terminal, allure for web
  reporterOptions: {
    allure: {
      outputDir: './e2e/results/allure-raw/',   // Output dir for raw report
    },
  },
  services: ['static-server'],
  staticServerFolders: [{ mount: '/', path: './src' }],
  staticServerPort: 8080,


  // ==================
  // Some nice defaults
  // ==================
  maxInstances: 10,
  sync: true,
  logLevel: 'silent',
  coloredLogs: true,
  deprecationWarnings: true,
  bail: 0,
  waitforTimeout: 10000,
  connectionRetryTimeout: 90000,
  connectionRetryCount: 3,
  framework: 'jasmine',
  jasmineNodeOpts: {
    defaultTimeoutInterval: 100000,
    expectationResultHandler: function(passed, assertion) {
    }
  },
};

module.exports = {
  config,
};

require("babel-core/register")({
  presets: ['es2015']
});

